@@ -1053,6 +1053,7 @@ gotoline_frame_create(Tbfwin * bfwin)
 
 	gtk_box_pack_start(GTK_BOX(hbox), gtk_label_new(_("Goto Line:")), FALSE, FALSE, 0);
 	bfwin->gotoline_entry = gtk_entry_new();
+	gtk_entry_set_width_chars(GTK_ENTRY(bfwin->gotoline_entry), 5);
 	gtk_box_pack_start(GTK_BOX(hbox), bfwin->gotoline_entry, FALSE, FALSE, 0);
 	g_signal_connect(bfwin->gotoline_entry, "changed", G_CALLBACK(gotoline_entry_changed), bfwin);
 	g_signal_connect(bfwin->gotoline_entry, "insert-text", G_CALLBACK(gotoline_entry_insert_text), NULL);
@@ -1671,15 +1672,15 @@ bfwin_create_main(Tbfwin * bfwin, gboolean with_new_doc)
 		gtk_box_pack_start(GTK_BOX(hbox), bfwin->statusbar, TRUE, TRUE, 0);
 		bfwin->statusbar_lncol = gtk_statusbar_new();
 		gtk_box_pack_start(GTK_BOX(hbox), bfwin->statusbar_lncol, FALSE, FALSE, 0);
-		/* I hope the 'w' is an average width character, the characters are usually not monospaced so these values are just averages that look good on most translations too */
+		/* I hope the 'x' is an average width character, the characters are usually not monospaced so these values are just averages that look good on most translations too */
 		onecharwidth = widget_get_string_size(bfwin->statusbar_lncol, "x");
 		gtk_widget_set_size_request(GTK_WIDGET(bfwin->statusbar_lncol), onecharwidth * 30, -1);
 		bfwin->statusbar_insovr = gtk_statusbar_new();
 		gtk_box_pack_start(GTK_BOX(hbox), bfwin->statusbar_insovr, FALSE, FALSE, 0);
-		gtk_widget_set_size_request(GTK_WIDGET(bfwin->statusbar_insovr), onecharwidth * 6, -1);
+		gtk_widget_set_size_request(GTK_WIDGET(bfwin->statusbar_insovr), onecharwidth * 3, -1);
 		bfwin->statusbar_editmode = gtk_statusbar_new();
 		gtk_box_pack_start(GTK_BOX(hbox), bfwin->statusbar_editmode, FALSE, FALSE, 0);
-		gtk_widget_set_size_request(GTK_WIDGET(bfwin->statusbar_editmode), onecharwidth * 35, -1);
+		gtk_widget_set_size_request(GTK_WIDGET(bfwin->statusbar_editmode), onecharwidth * 25, -1);
 #if GTK_CHECK_VERSION(3, 0, 0)
 		gtk_window_set_has_resize_grip(GTK_WINDOW(bfwin->main_window), TRUE);
 #else
